@@ -23,7 +23,7 @@ class Iotery:
         All API specifications can be found at https://iotery.io/v1/docs/embedded
     """
 
-    def __init__(self, base_url="https://api.iotery.io/v1"):
+    def __init__(self, api_key, base_url="https://api.iotery.io/v1"):
         self._api_key = api_key
         self._base_url = base_url
         self._headers = {
